<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:crane="http://www.CraneSoftwrights.com/ns/site"
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" 
                xmlns:dc="http://purl.org/dc/elements/1.1/" 
                xmlns:csl="http://www.CraneSoftwrights.com/ns/rss" 
                xmlns:ev="http://purl.org/rss/1.0/modules/event/" 
                xmlns:rss="http://purl.org/rss/1.0/"
                exclude-result-prefixes="crane"
                version="1.0">

<!-- $Id: cranerss.xsl,v 1.6 2008/11/18 02:11:08 gkholman Exp $ -->

<!-- This stylesheet is meant to be imported into another stylesheet for
     access and display of Crane's calendar of training courses.

     Just import this and call the template:

        {http://www.CraneSoftwrights.com/ns/misc}calendar-rss

     An example shell stylesheet is found in the ZIP package pointed to at:

        http://www.CraneSoftwrights.com/training/cranecal.htm

     The package as delivered uses a local filename reference for finding
     the RSS file; this must be changed by changing the parameter names
     to point to the remote filename reference.
-->

<xsl:template match="/rdf:RDF">
  <xsl:call-template name="crane:calendar-rss">
    <xsl:with-param name="crane" select="."/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="crane:calendar-rss">
  <xsl:param name="calendar-rss-remote"
    select="'http://www.CraneSoftwrights.com/training/crane-courses.rss'"/>
  <xsl:param name="calendar-rss"
    select="'crane-courses.rss'"/>
  <xsl:param name="crane" select="document($calendar-rss)/rdf:RDF"/>

  <xsl:variable name="deliveries" select="$crane/rss:item[ev:*]"/>
  <xsl:variable name="courses" select="$crane/rss:item[not(ev:*)]"/>

  <xsl:if test="not($crane)">
    <xsl:message terminate="yes">
      <xsl:text>Change the declaration for $calendar-rss parameter </xsl:text>
      <xsl:text>to find the required file.</xsl:text>
    </xsl:message>
  </xsl:if>

  <table summary="Summary of Crane's instructor-led training deliveries"
         border="1" width="100%">
    <tr>
      <td align="center"><b>Courses</b>
      <small> (<xsl:value-of select="$crane/rss:channel/dc:date"/>)</small>
      </td>
      <td align="center"><b>Locations</b></td>
      <td align="center"><b>Lengths</b></td>
      <td align="center"><b>Dates</b></td>
    </tr>
    <xsl:for-each select="$courses">
      <xsl:sort select="rss:title"/>
      <tr>
        <td valign="center" 
        rowspan="{count($deliveries[csl:course-id=current()/csl:course-id])}">
          <a href="{rss:link}" target="_blank">
            <xsl:value-of select="rss:title"/>
          </a>
          <small>
            <xsl:text> </xsl:text>
            <a href="{csl:syllabus/@rdf:resource}" style="white-space:nowrap"
              target="_blank">(syllabus)</a>
            <xsl:text> </xsl:text>
            <a href="{csl:past/@rdf:resource}" style="white-space:nowrap"
               target="_blank">(past deliveries)</a>
          </small>
        </td>
        <xsl:choose>
          <xsl:when test="$deliveries[csl:course-id=current()/csl:course-id]">
            <xsl:for-each 
                select="$deliveries[csl:course-id=current()/csl:course-id][1]">
              <xsl:call-template name="crane:delivery-rss"/>
            </xsl:for-each>
          </xsl:when>
          <xsl:otherwise>
            <td colspan="3" align="center">
              <xsl:text>(none scheduled at this time)</xsl:text>
            </td>
          </xsl:otherwise>
        </xsl:choose>
      </tr>
      <xsl:if test="$deliveries[csl:course-id=current()/csl:course-id][2]">
       <xsl:for-each select="$deliveries[csl:course-id=current()/csl:course-id]
                                        [position()>1]">
          <tr>
            <xsl:call-template name="crane:delivery-rss"/>
          </tr>
        </xsl:for-each>
      </xsl:if>
    </xsl:for-each>
  </table>
</xsl:template>

<xsl:template name="crane:delivery-rss">
  <td>
    <xsl:value-of select="ev:location"/>
    <xsl:for-each select="rss:link">
      <xsl:text> </xsl:text>
      <small>
        <a href="{.}" target="_blank">(info)</a>
      </small>
    </xsl:for-each>
    <xsl:for-each select="csl:pricing">
      <xsl:text> </xsl:text>
      <small>
        <a href="{@rdf:resource}" target="_blank">(pricing)</a>
      </small>
    </xsl:for-each>
    <xsl:for-each select="csl:host">
      <xsl:text> </xsl:text>
      <small>
        <a href="{@rdf:resource}" target="_blank">(host)</a>
      </small>
    </xsl:for-each>
    <xsl:for-each select="csl:registration">
      <xsl:text> </xsl:text>
      <small>
        <a href="../{@rdf:resource}" target="_blank">(registration)</a>
      </small>
    </xsl:for-each>
  </td>
  <td><xsl:value-of select="csl:length"/></td>
  <td>
    <span style="white-space:nowrap">
      <xsl:value-of select="ev:startdate"/>
    </span>
  </td>
</xsl:template>

</xsl:stylesheet>
